@@ -11,10 +11,6 @@ from dotenv import load_dotenv
 from url_remote.environment_name_enum import EnvironmentName
 
 from .mini_logger import MiniLogger as logger
-from .http_response import (create_authorization_http_headers,  # noqa - used for backwards compatibility
-                            get_user_jwt_from_event,
-                            create_return_http_headers, create_error_http_response, create_ok_http_response,
-                            create_http_body)
 
 load_dotenv()
 # TODO Let's do brainstorming on this
@@ -354,12 +350,13 @@ def obfuscate_log_dict(log_dict: dict) -> dict:
         if isinstance(value, dict):
             obfuscated_log_dict[key] = obfuscate_log_dict(value)
         elif re.search(r'password|secret|token|jwt|e[\-_]?mail|phone|name|address|ssn', key, re.IGNORECASE):
-           # TODO Maybe we can reveal a small part
+            # TODO Maybe we can reveal a small part
             obfuscated_log_dict[key] = "***"
         else:
             obfuscated_log_dict[key] = value
     return obfuscated_log_dict
 
+
 # TODO: add tests to the following functions
 
 def remove_digits(text: str) -> str:
@@ -415,3 +412,16 @@ def get_ip_v4():
 
 def get_ip_v6():
     return requests.get('https://api.seeip.org/jsonip').json()['ip']
+
+
+def snake_to_camel(snake_str: str) -> str:
+    """Converts snake_case to camelCase."""
+    components = snake_str.split('_')
+    camel_str = components[0] + ''.join(x.title() for x in components[1:])
+    return camel_str
+
+
+def camel_to_snake(camel_str: str) -> str:
+    """Converts camelCase to snake_case."""
+    snake_str = re.sub(r'(?<!^)(?=[A-Z])', '_', camel_str).lower()
+    return snake_str
